-- #hide
-----------------------------------------------------------------------------
-- |
-- Module      :  OS.Menu
-- Copyright   :  (c) Krasimir Andreev 2002
-- License     :  BSD-style
-- 
-- Maintainer  :  ka2_mail@yahoo.com
-- Stability   :  provisional
-- Portability :  portable
--
-----------------------------------------------------------------------------

module Graphics.UI.ObjectIO.OS.Menu where


import	Graphics.UI.ObjectIO.OS.MenuCrossCall_12
import	Graphics.UI.ObjectIO.OS.DocumentInterface(OSMenuBar(..))
import	Graphics.UI.ObjectIO.OS.Types(OSWindowPtr, osNoWindowPtr)
import  Control.Monad(when)
import  Data.Char(toUpper)


--	Types for menus and menu elements:
type	OSMenuHandle	= HMENU
type	OSMenu		= HMENU
type	OSMenuItem	= HITEM

--	Dummy values:
osNoMenu 		= 0 :: OSMenu
osNoMenuItem 		= 0 :: OSMenuItem

--	Enabling and disabling menus and menu elements:

osDisableMenu :: OSMenu -> OSMenuBar -> IO ()
osDisableMenu submenu osMenuBar@(OSMenuBar {menuBar=menuBar})
	= winChangeMenuAbility menuBar submenu False

osEnableMenu :: OSMenu -> OSMenuBar -> IO ()
osEnableMenu submenu osMenuBar@(OSMenuBar {menuBar=menuBar})
	= winChangeMenuAbility menuBar submenu True

osEnableMenuItem :: OSMenu -> OSMenuItem -> IO ()
osEnableMenuItem menuHandle item
	= winChangeItemAbility menuHandle item True

osDisableMenuItem :: OSMenu -> OSMenuItem -> IO ()
osDisableMenuItem menuHandle item
	= winChangeItemAbility menuHandle item False


--	Changing and updating the menu bar:

drawMenuBar :: OSMenuBar -> IO ()
drawMenuBar (OSMenuBar {menuWindow=menuWindow,menuClient=menuClient})
	= winDrawMenuBar menuWindow (if (menuClient==osNoWindowPtr) then 0 else menuClient)

osMenuBarClear :: IO ()
osMenuBarClear = return ()

osMenuBarSet :: OSMenuBar -> IO ()
osMenuBarSet menuBar = return ()
	
osMenuInsert :: Int -> String -> OSMenuBar -> IO OSMenu
osMenuInsert index title mbar = do
	menu <- winCreatePopupMenuHandle
	winInsertMenu title True menu (menuBar mbar) index
	return menu
	
osSubMenuInsert :: Int -> String -> OSMenu -> IO (OSMenu, OSMenu)
osSubMenuInsert index title parentMenu = do
	menu <- winCreatePopupMenuHandle
	winInsertMenu title True menu parentMenu index
	return (menu,parentMenu)

osMenuRemove :: OSMenu -> OSMenuBar -> IO ()
osMenuRemove menu menuBar@(OSMenuBar {menuBar=hmenu}) = do
	winDeleteMenu hmenu menu
	winDestroyMenu menu
	return ()

osSubMenuRemove :: OSMenu -> OSMenu -> IO ()
osSubMenuRemove submenu hmenu = do
	winDeleteMenu hmenu submenu
	winDestroyMenu submenu
	return ()

osCreatePopUpMenu :: IO OSMenu
osCreatePopUpMenu = winCreatePopupMenuHandle

osTrackPopUpMenu :: OSMenu -> OSWindowPtr -> IO Bool
osTrackPopUpMenu menu framePtr = winTrackPopupMenu menu framePtr


--	Changing (sub)menus:
osAppendMenuItem :: OSMenuBar -> Int -> OSMenu -> String -> Bool -> Bool -> Char -> IO OSMenuItem
osAppendMenuItem (OSMenuBar {menuWindow=menuWindow}) index menu title able mark key =
	winInsertMenuItem title able mark key menuWindow menu index

osAppendMenuSeparator :: Int -> OSMenu -> IO OSMenuItem
osAppendMenuSeparator index menu =
	winInsertSeparator menu index

osChangeMenuTitle :: OSMenuBar -> OSMenu -> String -> IO ()
osChangeMenuTitle (OSMenuBar {menuBar=menuBar}) menu title = winModifyMenu title menu menuBar

osChangeMenuItemTitle :: OSMenu -> OSMenuItem -> String -> IO ()
osChangeMenuItemTitle menu item title = winModifyMenuItem title item menu

osMenuItemCheck :: Bool -> OSMenu -> OSMenuItem -> IO ()
osMenuItemCheck check menu item = winChangeMenuItemCheck menu item check

osMenuRemoveItem :: OSMenuItem -> OSMenu -> IO ()
osMenuRemoveItem item menu = winRemoveMenuItem menu item

