-- #hide
-----------------------------------------------------------------------------
-- |
-- Module      :  OS.MenuCrossCall_12
-- Copyright   :  (c) Krasimir Andreev 2002
-- License     :  BSD-style
-- 
-- Maintainer  :  ka2_mail@yahoo.com
-- Stability   :  provisional
-- Portability :  portable
--
-- OS.MenuCrossCall_12 contains all cross calls for menu handling.
--
-----------------------------------------------------------------------------

module Graphics.UI.ObjectIO.OS.MenuCrossCall_12
		( HITEM, HMENU
		, winCreatePopupMenuHandle, winTrackPopupMenu, winInsertMenu
		, winInsertMenuItem, winInsertSeparator, winChangeMenuItemCheck
		, winModifyMenu, winModifyMenuItem, winDestroyMenu
		, winDeleteMenu, winRemoveMenuItem, winChangeItemAbility, winChangeMenuAbility 
		, winDrawMenuBar, winRemoveMenuShortKey 
		) where


import Graphics.UI.ObjectIO.OS.ClCrossCall_12
import Graphics.UI.ObjectIO.OS.Cutil_12
import Graphics.UI.ObjectIO.OS.Types(HWND)
import Foreign.Marshal.Utils(fromBool)
import Data.Char(ord)

type	HITEM	= Int
type	HMENU	= Int

winCreatePopupMenuHandle :: IO HMENU
winCreatePopupMenuHandle = do
	rcci <- issueCleanRequest2 (errorCallback2 "CreatePopupMenuHandle ") (rq0Cci ccRqCREATEPOPMENU)
	let hmenu =
		if ccMsg rcci == ccRETURN1 then p1 rcci else
		if ccMsg rcci == ccWASQUIT then 0	else
					        error "[CreatePopupMenuHandle] expected CcRETURN1 value."
	return hmenu

winTrackPopupMenu :: HMENU -> HWND -> IO Bool
winTrackPopupMenu menu framePtr = do
	rcci <- issueCleanRequest2 (errorCallback2 "TrackPopupMenu") (rq2Cci ccRqTRACKPOPMENU menu framePtr)
	let ok = 
		if ccMsg rcci == ccRETURN1 then p1 rcci /= 0 else
	  	if ccMsg rcci == ccWASQUIT then False	     else
	  				        error "[TrackPopupMenu] expected CcRETURN1 value."
	return ok

winInsertMenu :: String -> Bool -> HMENU -> HMENU -> Int -> IO ()
winInsertMenu text state submenu menu pos = do
	textPtr <- newCString text
	issueCleanRequest2 (errorCallback2 "AppendMenu") (rq5Cci ccRqINSERTMENU (fromBool state) menu (addr2int textPtr) submenu pos)
	free textPtr

winInsertMenuItem :: String -> Bool -> Bool -> Char -> HWND -> HMENU -> Int -> IO HITEM
winInsertMenuItem text ablestate markstate key menuWindow menu pos = do
	textPtr <- newCString text
	let insertCci = rq6Cci ccRqINSERTMENUITEM ((fromBool ablestate)*2 + (fromBool markstate)) menuWindow menu (addr2int textPtr) (ord key) pos
	rcci <- issueCleanRequest2 (errorCallback2 "InsertMenuItem") insertCci
	let hitem =
		if ccMsg rcci == ccRETURN1 then p1 rcci else
		if ccMsg rcci == ccWASQUIT then 0       else
						error "[winInsertMenuItem] expected CcRETURN1 value."
	free textPtr
	return hitem

winInsertSeparator :: HMENU -> Int -> IO HITEM
winInsertSeparator menu pos = do
	rcci <- issueCleanRequest2 (errorCallback2 "InsertSeparator") (rq2Cci ccRqINSERTSEPARATOR menu pos)
	let hitem =
		if ccMsg rcci == ccRETURN1 then p1 rcci else
		if ccMsg rcci == ccWASQUIT then 0       else
					        error "[winInsertSeparator] expected CcRETURN1 value."
	return hitem

winChangeMenuItemCheck :: HMENU -> HITEM -> Bool -> IO ()
winChangeMenuItemCheck menu hitem state = do
	issueCleanRequest2 (errorCallback2 "CheckMenuItem") (rq3Cci ccRqCHECKMENUITEM menu hitem (fromBool state))
	return ()

winModifyMenu :: String -> HMENU -> HMENU -> IO ()
winModifyMenu text submenu menu = do
	textPtr <- newCString text
	issueCleanRequest2 (errorCallback2 "ModifyMenu") (rq3Cci ccRqMODIFYMENU submenu menu (addr2int textPtr))
	free textPtr

winModifyMenuItem :: String -> HITEM -> HMENU -> IO ()
winModifyMenuItem text hitem menu = do
	textPtr <- newCString text
	issueCleanRequest2 (errorCallback2 "ModifyMenuItem") (rq3Cci ccRqMODIFYMENUITEM hitem menu (addr2int textPtr))
	free textPtr

winDestroyMenu :: HMENU -> IO ()
winDestroyMenu menu = do
	issueCleanRequest2 (errorCallback2 "DestroyMenu") (rq1Cci ccRqDESTROYMENU menu)
	return ()

winDeleteMenu :: HMENU -> HITEM -> IO ()
winDeleteMenu menu hitem = do
	issueCleanRequest2 (errorCallback2 "DeleteMenu") (rq2Cci ccRqDELETEMENU menu hitem)
	return ()

winRemoveMenuItem :: HMENU -> HITEM -> IO ()
winRemoveMenuItem menu hitem = do
	issueCleanRequest2 (errorCallback2 "RemoveMenuItem") (rq2Cci ccRqREMOVEMENUITEM menu hitem)
	return ()

winChangeItemAbility :: HMENU -> HITEM -> Bool -> IO ()
winChangeItemAbility parent hitem onoff = do
	issueCleanRequest2 (errorCallback2 "ChangeItemAbility") (rq3Cci ccRqITEMENABLE parent hitem (fromBool onoff))
	return ()

winChangeMenuAbility :: HMENU -> HMENU -> Bool -> IO ()
winChangeMenuAbility parent submenu onoff = do
	issueCleanRequest2 (errorCallback2 "ChangeMenuAbility") (rq3Cci ccRqMENUENABLE parent submenu (fromBool onoff))
	return ()

winDrawMenuBar :: HWND -> HWND -> IO ()
winDrawMenuBar framePtr clientPtr = do
	issueCleanRequest2 (errorCallback2 "DrawMenuBar") (rq2Cci ccRqDRAWMBAR framePtr clientPtr)
	return ()

winRemoveMenuShortKey :: HWND -> Int -> IO ()
winRemoveMenuShortKey framePtr cmd = do
	issueCleanRequest2 (errorCallback2 "RemoveMenuShortKey") (rq2Cci ccRqREMOVEMENUSHORTKEY framePtr cmd)
	return ()
